@@ -579,6 +579,7 @@ make_iso (const char *filename, const char *label)
 
 	cd_progress_set_text (_("Creating CD image"));
 	cd_progress_set_fraction (0.0);
+	cd_progress_set_image_spinning (TRUE);
 	error = NULL;
 	if (!g_spawn_async_with_pipes  (NULL,
 					(char **)argv,
@@ -634,6 +635,7 @@ make_iso (const char *filename, const char *label)
 	g_free (state.emptydir);
 	rmdir (tempdir);
 	g_free (tempdir);
+	cd_progress_set_image_spinning (FALSE);
 
 	return mkisofs_output.result;
 }
